--- glossary.module	2008-09-04 06:40:14.000000000 +1200
+++ glossary.module	2009-07-03 16:58:14.689375000 +1200
@@ -522,7 +522,12 @@
 
         default:
           // Icon format.
-          $img = '<img src="'. variable_get("glossary_icon_$format", "glossary.gif") .'" title="'. $term_title .'" />';
+          $img_attr = array(
+            'src'   => variable_get("glossary_icon_$format", "glossary.gif"),
+            'alt'   => variable_get("glossary_icon_alt_$format", "[define]"),
+            'title' => $term_title,
+          );
+          $img = '<img'. drupal_attributes($img_attr) .' />';
           if ($link_style == 'none') {
             $ins_after .= $img;
           }
@@ -1679,6 +1684,17 @@
     '#suffix' => '</div>',
     );
 
+  $form['filter']['indicator']["glossary_icon_alt"] = array(
+    '#type' => 'textfield',
+    '#title' => t('Glossary Icon ALT text'),
+    '#default_value' => variable_get("glossary_icon_alt_$format", '[define]'),
+    '#size' => 50,
+    '#maxlength' => 255,
+    '#description' => t('If you chose "icon" above, enter the text which will replace the icon if the user cannot view images.'),
+    '#prefix' => '<div class="glossary_icon_alt">',
+    '#suffix' => '</div>',
+    );
+
   $form['submit'] = array(
     '#type' => 'submit',
     '#value' => t('Save configuration'),
@@ -1712,6 +1728,7 @@
   variable_set("glossary_replace_$format", $form_values["glossary_replace"]);
   variable_set("glossary_superscript_$format", $form_values["glossary_superscript"]);
   variable_set("glossary_icon_$format", $form_values["glossary_icon"]);
+  variable_set("glossary_icon_alt_$format", $form_values["glossary_icon_alt"]);
   drupal_set_message(t('Configuration has been updated.'));
 
   return;
@@ -1724,4 +1741,4 @@
   else {
     return t('Click one of the letters above to advance the page to terms beginning with that letter.');
   }
-}
\ No newline at end of file
+}
--- glossary.js	2008-06-30 06:26:13.000000000 +1200
+++ glossary.js	2009-07-03 16:53:07.580000000 +1200
@@ -9,12 +9,14 @@
     $("input[@name=glossary_superscript]").parents("div.glossary_superscript").hide();
   }
 
   // Disable icon URL field if not selected.
   if ($("input[@name=glossary_replace]:checked").val() == 'icon') {
     $("input[@name=glossary_icon]").parents("div.glossary_icon").show();
+    $("input[@name=glossary_icon_alt]").parents("div.glossary_icon_alt").show();
   }
   else {
     $("input[@name=glossary_icon]").parents("div.glossary_icon").hide();;
+    $("input[@name=glossary_icon_alt]").parents("div.glossary_icon_alt").hide();;
   }
 }
 
@@ -9,12 +9,14 @@
   }
 
-  // Disable icon URL field if not selected.
+  // Disable icon URL and ALT fields if not selected.
   if ($("input[@name=glossary_replace]:checked").val() == 'icon') {
     $("input[@name=glossary_icon]").parents("div.glossary_icon").show();
